@@ -3,13 +3,13 @@ import datetime
 from sqlalchemy import Column, String, Integer, DateTime, Table, ForeignKey, Text
 from sqlalchemy.orm import relationship
 from sqlalchemy_utils import UUIDType
+from sqlalchemy_serializer import SerializerMixin
 import uuid
 
-
-class Entity(Base):
+class Entity(Base, SerializerMixin):
     
     __abstract__  = True
-
+    serialize_only = ('id', 'date_created','date_modified', 'name', 'description')
     id = Column(Integer, primary_key=True)
     uuid = Column(UUIDType(binary=False), unique=True, nullable=False, default=uuid.uuid4)
     date_created  = Column(DateTime,  default=datetime.datetime.utcnow)
@@ -24,7 +24,4 @@ class Entity(Base):
     
     def __repr__(self):
         return super().__repr__()
-    
-    
-    
     
\ No newline at end of file
